@@ -1,11 +1,10 @@
-friedmanmc<-function(y,groups,blocks,probs=0.05){
+
+friedmanmc<-function(y,groups,blocks,alpha=0.05){
 
     if ((is.matrix(y)) | (is.data.frame(y))){
         groups <- factor(c(col(y)))
         blocks <- factor(c(row(y)))
-    }                          
-    
-    else {
+    } else {
         if (any(is.na(groups)) || any(is.na(blocks))) 
             stop("NA's are not allowed in groups or blocks")
         if (any(diff(c(length(y), length(groups), length(blocks))))) 
@@ -32,9 +31,10 @@ friedmanmc<-function(y,groups,blocks,probs=0.05){
 
     names(dif)<-noms
     dif1<-dif
-    alpha<-qnorm(probs/(k*(k-1)),lower.tail=FALSE)*sqrt((N*k*(k+1))/6)
+    alphadif<-qnorm(alpha/(k*(k-1)),lower.tail=FALSE)*sqrt((N*k*(k+1))/6)
+    pval<-pnorm(-abs(dif1), sd=sqrt(N*k*(k+1)/6))*k*(k+1);pval<-ifelse(pval>1,1,pval)
     meth<-"Multiple comparisons between groups after Friedman test"
-    output<-list(statistic=meth, p.value=probs, dif.com=data.frame(obs.dif=dif1,critical.dif=alpha,difference=ifelse((dif1-alpha)>0,TRUE,FALSE)))
+    output<-list(statistic=meth, alpha=alpha, dif.com=data.frame(obs.dif=dif1,critical.dif=alphadif,stat.signif=ifelse((dif1-alphadif)>0,TRUE,FALSE),p.value=pval))
     class(output)<-c("mc","list")
     output
 }
